@@ -25,11 +25,15 @@
 */
 
 #include <kdb/extern.h>
-#include "wcolidx-priv.h"
-#include "widxblk-priv.h"
-#include "werror-priv.h"
+
+#include "wcolidx.h"
+#include "widxblk.h"
+
+#include "werror.h"
+
 #include <kfs/file.h>
 #include <kfs/md5.h>
+
 #include <sysalloc.h>
 
 #include <limits.h>
@@ -40,7 +44,7 @@
 
 
 /*--------------------------------------------------------------------------
- * KColumnIdx
+ * KWColumnIdx
  *  the index fork
  */
 
@@ -48,16 +52,16 @@
 /* EstablishIdRange
  */
 static
-void KColumnIdxEstablishIdRange ( KColumnIdx *self )
+void KWColumnIdxEstablishIdRange ( KWColumnIdx *self )
 {
     int64_t first, upper;
 
-    if ( ! KColumnIdx0IdRange ( & self -> idx0, & self -> id_first, & self -> id_upper ) )
+    if ( ! KWColumnIdx0IdRange ( & self -> idx0, & self -> id_first, & self -> id_upper ) )
     {
-        if ( ! KColumnIdx1IdRange ( & self -> idx1, & self -> id_first, & self -> id_upper ) )
+        if ( ! KWColumnIdx1IdRange ( & self -> idx1, & self -> id_first, & self -> id_upper ) )
             self -> id_first = self -> id_upper = 1;
     }
-    else if ( KColumnIdx1IdRange ( & self -> idx1, & first, & upper ) )
+    else if ( KWColumnIdx1IdRange ( & self -> idx1, & first, & upper ) )
     {
         if ( self -> id_first > first )
             self -> id_first = first;
@@ -69,7 +73,7 @@ void KColumnIdxEstablishIdRange ( KColumnIdx *self )
 
 /* Create
  */
-rc_t KColumnIdxCreate ( KColumnIdx *self, KDirectory *dir,
+rc_t KWColumnIdxCreate ( KWColumnIdx *self, KDirectory *dir,
     KMD5SumFmt *md5, KCreateMode mode, uint64_t *data_eof,
     size_t pgsize, int32_t checksum )
 {
@@ -79,28 +83,28 @@ rc_t KColumnIdxCreate ( KColumnIdx *self, KDirectory *dir,
 
     assert ( self != NULL );
 
-    rc = KColumnIdx1Create ( & self -> idx1, dir, md5, mode,
+    rc = KWColumnIdx1Create ( & self -> idx1, dir, md5, mode,
         data_eof, & idx0_count, & idx2_eof, pgsize, checksum );
     if ( rc == 0 )
     {
         rc = ( self -> idx1 . vers < 3 ) ?
-            KColumnIdx0Create_v1 ( & self -> idx0, dir, md5, mode, self -> idx1 . bswap ):
-            KColumnIdx0Create ( & self -> idx0, dir, idx0_count, md5, mode, self -> idx1 . bswap );
+            KWColumnIdx0Create_v1 ( & self -> idx0, dir, md5, mode, self -> idx1 . bswap ):
+            KWColumnIdx0Create ( & self -> idx0, dir, idx0_count, md5, mode, self -> idx1 . bswap );
         if ( rc == 0 )
         {
-            rc = KColumnIdx2Create ( & self -> idx2, dir, md5, mode, idx2_eof );
+            rc = KWColumnIdx2Create ( & self -> idx2, dir, md5, mode, idx2_eof );
             if ( rc == 0 )
             {
-                KColumnIdxEstablishIdRange ( self );
+                KWColumnIdxEstablishIdRange ( self );
 
                 /* successful return */
                 return 0;
             }
 
-            KColumnIdx0Whack ( & self -> idx0 );
+            KWColumnIdx0Whack ( & self -> idx0 );
         }
 
-        KColumnIdx1Whack ( & self -> idx1 );
+        KWColumnIdx1Whack ( & self -> idx1 );
     }
 
     /* failure return */
@@ -109,7 +113,7 @@ rc_t KColumnIdxCreate ( KColumnIdx *self, KDirectory *dir,
 
 /* Open
  */
-rc_t KColumnIdxOpenRead ( KColumnIdx *self, const KDirectory *dir,
+rc_t KWColumnIdxOpenRead ( KWColumnIdx *self, const KDirectory *dir,
     uint64_t *data_eof, size_t *pgsize, int32_t *checksum )
 {
     rc_t rc;
@@ -118,32 +122,32 @@ rc_t KColumnIdxOpenRead ( KColumnIdx *self, const KDirectory *dir,
 
     assert ( self != NULL );
 
-    rc = KColumnIdx1OpenRead ( & self -> idx1,
+    rc = KWColumnIdx1OpenRead ( & self -> idx1,
         dir, data_eof, & idx0_count, & idx2_eof, pgsize, checksum );
     if ( rc == 0 )
     {
         rc = ( self -> idx1 . vers < 3 ) ?
-            KColumnIdx0OpenRead_v1 ( & self -> idx0, dir, self -> idx1 . bswap ):
-            KColumnIdx0OpenRead ( & self -> idx0, dir, idx0_count, self -> idx1 . bswap );
+            KWColumnIdx0OpenRead_v1 ( & self -> idx0, dir, self -> idx1 . bswap ):
+            KWColumnIdx0OpenRead ( & self -> idx0, dir, idx0_count, self -> idx1 . bswap );
         if ( rc == 0 )
         {
-            rc = KColumnIdx2OpenRead ( & self -> idx2, dir, idx2_eof );
+            rc = KWColumnIdx2OpenRead ( & self -> idx2, dir, idx2_eof );
             if ( rc == 0 || GetRCState ( rc ) == rcNotFound )
             {
-                KColumnIdxEstablishIdRange ( self );
+                KWColumnIdxEstablishIdRange ( self );
                 return 0;
             }
 
-            KColumnIdx0Whack ( & self -> idx0 );
+            KWColumnIdx0Whack ( & self -> idx0 );
         }
 
-        KColumnIdx1Whack ( & self -> idx1 );
+        KWColumnIdx1Whack ( & self -> idx1 );
     }
 
     return rc;
 }
 
-rc_t KColumnIdxOpenUpdate ( KColumnIdx *self, KDirectory *dir,
+rc_t KWColumnIdxOpenUpdate ( KWColumnIdx *self, KDirectory *dir,
     KMD5SumFmt *md5, uint64_t *data_eof, size_t *pgsize, int32_t *checksum )
 {
     rc_t rc;
@@ -152,25 +156,25 @@ rc_t KColumnIdxOpenUpdate ( KColumnIdx *self, KDirectory *dir,
 
     assert ( self != NULL );
 
-    rc = KColumnIdx1OpenUpdate ( & self -> idx1, dir,
+    rc = KWColumnIdx1OpenUpdate ( & self -> idx1, dir,
         md5, data_eof, & idx0_count, & idx2_eof, pgsize, checksum );
     if ( rc == 0 )
     {
         rc = ( self -> idx1 . vers < 3 ) ?
-            KColumnIdx0Create_v1 ( & self -> idx0, dir, md5, kcmOpen, self -> idx1 . bswap ):
-            KColumnIdx0Create ( & self -> idx0, dir, idx0_count, md5, kcmOpen, self -> idx1 . bswap );
+            KWColumnIdx0Create_v1 ( & self -> idx0, dir, md5, kcmOpen, self -> idx1 . bswap ):
+            KWColumnIdx0Create ( & self -> idx0, dir, idx0_count, md5, kcmOpen, self -> idx1 . bswap );
         if ( rc == 0 )
         {
-            rc = KColumnIdx2Create ( & self -> idx2, dir, md5, kcmOpen, idx2_eof );
+            rc = KWColumnIdx2Create ( & self -> idx2, dir, md5, kcmOpen, idx2_eof );
             if ( rc == 0 )
             {
-                KColumnIdxEstablishIdRange ( self );
+                KWColumnIdxEstablishIdRange ( self );
                 return 0;
             }
 
-            KColumnIdx0Whack ( & self -> idx0 );
+            KWColumnIdx0Whack ( & self -> idx0 );
         }
-        KColumnIdx1Whack ( & self -> idx1 );
+        KWColumnIdx1Whack ( & self -> idx1 );
     }
 
     return rc;
@@ -178,7 +182,7 @@ rc_t KColumnIdxOpenUpdate ( KColumnIdx *self, KDirectory *dir,
 
 /* Whack
  */
-rc_t KColumnIdxWhack ( KColumnIdx *self,
+rc_t KWColumnIdxWhack ( KWColumnIdx *self,
     uint64_t data_eof, size_t pgsize, int32_t checksum )
 {
     rc_t rc;
@@ -187,7 +191,7 @@ rc_t KColumnIdxWhack ( KColumnIdx *self,
 
     if ( self -> commit_count != 0 )
     {
-        rc = KColumnIdx1WriteHeader ( & self -> idx1,
+        rc = KWColumnIdx1WriteHeader ( & self -> idx1,
             data_eof, self -> idx0 . count, self -> idx2 . eof,
             pgsize, checksum );
         if ( rc != 0 )
@@ -196,11 +200,11 @@ rc_t KColumnIdxWhack ( KColumnIdx *self,
         self -> commit_count = 0;
     }
 
-    rc = KColumnIdx1Whack ( & self -> idx1 );
+    rc = KWColumnIdx1Whack ( & self -> idx1 );
     if ( rc == 0 )
     {
-        KColumnIdx0Whack ( & self -> idx0 );
-        KColumnIdx2Whack ( & self -> idx2 );
+        KWColumnIdx0Whack ( & self -> idx0 );
+        KWColumnIdx2Whack ( & self -> idx2 );
     }
 
     return rc;
@@ -208,17 +212,17 @@ rc_t KColumnIdxWhack ( KColumnIdx *self,
 
 /* Version
  */
-#ifndef KColumnIdxVersion
-rc_t KColumnIdxVersion ( const KColumnIdx *self, uint32_t *version )
+#ifndef KWColumnIdxVersion
+rc_t KWColumnIdxVersion ( const KWColumnIdx *self, uint32_t *version )
 {
-    return KColumnIdx1Version ( & self -> idx1, version );
+    return KWColumnIdx1Version ( & self -> idx1, version );
 }
 #endif
 
 /* IdRange
  *  returns range of ids contained within
  */
-rc_t KColumnIdxIdRange ( const KColumnIdx *self,
+rc_t KWColumnIdxIdRange ( const KWColumnIdx *self,
     int64_t *first, int64_t *last )
 {
     assert ( self != NULL );
@@ -235,7 +239,7 @@ rc_t KColumnIdxIdRange ( const KColumnIdx *self,
 
 /* FindFirstRowId
  */
-rc_t KColumnIdxFindFirstRowId ( const KColumnIdx * self,
+rc_t KWColumnIdxFindFirstRowId ( const KWColumnIdx * self,
     int64_t * found, int64_t start )
 {
     rc_t rc0, rc1;
@@ -250,7 +254,7 @@ rc_t KColumnIdxFindFirstRowId ( const KColumnIdx * self,
         return RC ( rcDB, rcColumn, rcSelecting, rcRow, rcNotFound );
 
     /* look in idx0 */
-    rc0 = KColumnIdx0FindFirstRowId ( & self -> idx0, found, start );
+    rc0 = KWColumnIdx0FindFirstRowId ( & self -> idx0, found, start );
     if ( rc0 == 0 )
     {
         if ( * found == start )
@@ -261,8 +265,8 @@ rc_t KColumnIdxFindFirstRowId ( const KColumnIdx * self,
     }
 
     /* look in main index */
-    /* KColumnIdx1LocateFirstRowIdBlob returns the blob containing 'start', if such blob exists, otherwise the next blob (or RC if there's no next) */
-    rc1 = KColumnIdx1LocateFirstRowIdBlob ( & self -> idx1, & bloc, start );
+    /* KWColumnIdx1LocateFirstRowIdBlob returns the blob containing 'start', if such blob exists, otherwise the next blob (or RC if there's no next) */
+    rc1 = KWColumnIdx1LocateFirstRowIdBlob ( & self -> idx1, & bloc, start );
     if ( rc1 != 0 )
     {
         return rc0;
@@ -296,7 +300,7 @@ rc_t KColumnIdxFindFirstRowId ( const KColumnIdx * self,
 /* LocateBlob
  *  locate an existing blob
  */
-rc_t KColumnIdxLocateBlob ( const KColumnIdx *self,
+rc_t KWColumnIdxLocateBlob ( const KWColumnIdx *self,
     KColBlobLoc *loc, int64_t first, int64_t upper )
 {
     rc_t rc;
@@ -312,17 +316,17 @@ rc_t KColumnIdxLocateBlob ( const KColumnIdx *self,
         return RC ( rcDB, rcColumn, rcSelecting, rcBlob, rcNotFound );
 
     /* look in idx0 */
-    rc = KColumnIdx0LocateBlob ( & self -> idx0, loc, first, upper );
+    rc = KWColumnIdx0LocateBlob ( & self -> idx0, loc, first, upper );
     if ( GetRCState ( rc ) == rcNotFound )
     {
         KColBlockLoc bloc;
 
         /* find block containing range */
-        rc = KColumnIdx1LocateBlock ( & self -> idx1, & bloc, first, upper );
+        rc = KWColumnIdx1LocateBlock ( & self -> idx1, & bloc, first, upper );
         if ( rc == 0 )
         {
             /* find location in idx2 */
-            rc = KColumnIdx2LocateBlob ( & self -> idx2,
+            rc = KWColumnIdx2LocateBlob ( & self -> idx2,
                 loc, & bloc, first, upper, self -> idx1 . bswap );
         }
     }
@@ -330,12 +334,12 @@ rc_t KColumnIdxLocateBlob ( const KColumnIdx *self,
     return rc;
 }
 
-/* KColumnIdxCommit
+/* KWColumnIdxCommit
  *  writes a new blob location to idx0
  *  updates idx1 with header information
  *  this should be the final step in committing a write operation
  */
-rc_t KColumnIdxCommit ( KColumnIdx *self, KMD5SumFmt *md5,
+rc_t KWColumnIdxCommit ( KWColumnIdx *self, KMD5SumFmt *md5,
     const KColBlobLoc *loc, uint32_t commit_freq,
     uint64_t data_eof, size_t pgsize, int32_t checksum )
 {
@@ -351,14 +355,14 @@ rc_t KColumnIdxCommit ( KColumnIdx *self, KMD5SumFmt *md5,
 
     /* journal to idx0 */
     rc = idx0rc =
-        KColumnIdx0Commit ( & self -> idx0, loc, & prior, self -> idx1 . bswap );
+        KWColumnIdx0Commit ( & self -> idx0, loc, & prior, self -> idx1 . bswap );
     if ( rc == 0 || rc == kdbReindex )
     {
         rc = 0;
 
         if ( ++ self -> commit_count >= commit_freq )
         {
-            rc = KColumnIdx1WriteHeader ( & self -> idx1,
+            rc = KWColumnIdx1WriteHeader ( & self -> idx1,
                 data_eof, self -> idx0 . count, self -> idx2 . eof,
                 pgsize, checksum );
             if ( rc == 0 )
@@ -389,28 +393,28 @@ rc_t KColumnIdxCommit ( KColumnIdx *self, KMD5SumFmt *md5,
         }
 
         /* revert idx0 commit */
-        KColumnIdx0Revert ( & self -> idx0, loc, & prior );
+        KWColumnIdx0Revert ( & self -> idx0, loc, & prior );
     }
 
     return rc;
 }
 
-rc_t KColumnIdxCommitDone ( KColumnIdx * self )
+rc_t KWColumnIdxCommitDone ( KWColumnIdx * self )
 {
     rc_t rc = 0;
 
     assert ( self != NULL );
-    rc = KColumnIdx1CommitDone ( & self -> idx1 );
+    rc = KWColumnIdx1CommitDone ( & self -> idx1 );
     if ( rc == 0 )
-	rc = KColumnIdx0CommitDone ( & self -> idx0 );
+	rc = KWColumnIdx0CommitDone ( & self -> idx0 );
     if ( rc == 0 )
-	rc = KColumnIdx2CommitDone ( & self -> idx2 );
+	rc = KWColumnIdx2CommitDone ( & self -> idx2 );
     return rc;
 }
 
-/* KColumnIdxRecordIdx0Edges
+/* KWColumnIdxRecordIdx0Edges
  *  creates tentative idx1 blocks from idx0 entries
- *  at the block type edges as identified by KColumnIdx0
+ *  at the block type edges as identified by KWColumnIdx0
  */
 typedef struct Idx0EdgeNode Idx0EdgeNode;
 struct Idx0EdgeNode
@@ -426,7 +430,7 @@ void CC Idx0EdgeNodeWhack ( DLNode *n, void *ignore )
 }
 
 static
-rc_t KColumnIdxRecordIdx0Edges ( const KColBlockLocInfo *info, void *edges )
+rc_t KWColumnIdxRecordIdx0Edges ( const KColBlockLocInfo *info, void *edges )
 {
     Idx0EdgeNode *node;
 
@@ -453,12 +457,12 @@ rc_t KColumnIdxRecordIdx0Edges ( const KColBlockLocInfo *info, void *edges )
     return 0;
 }
 
-/* KColumnIdxCollapseBlocks
+/* KWColumnIdxCollapseBlocks
  *  scans over blocks, looking for opportunities to
  *  combine them and collapse their number
  */
 static
-rc_t KColumnIdxCollapseBlocks ( KColumnIdx *self, DLList *edges )
+rc_t KWColumnIdxCollapseBlocks ( KWColumnIdx *self, DLList *edges )
 {
     uint32_t count;
 
@@ -531,14 +535,14 @@ rc_t KColumnIdxCollapseBlocks ( KColumnIdx *self, DLList *edges )
 }
 
 
-/* KColumnIdxWriteNewBlock
+/* KWColumnIdxWriteNewBlock
  *  writes each block into idx1 and idx2
  */
 typedef struct WriteNewBlockData WriteNewBlockData;
 struct WriteNewBlockData
 {
     uint64_t data_eof;
-    KColumnIdx *idx;
+    KWColumnIdx *idx;
     size_t pgsize;
     uint32_t commit_freq;
     int32_t checksum;
@@ -547,11 +551,11 @@ struct WriteNewBlockData
 };
 
 static
-bool CC KColumnIdxWriteNewBlock ( DLNode *n, void *data )
+bool CC KWColumnIdxWriteNewBlock ( DLNode *n, void *data )
 {
     WriteNewBlockData *pb = data;
     const Idx0EdgeNode *node = ( const Idx0EdgeNode* ) n;
-    KColumnIdx *self = pb -> idx;
+    KWColumnIdx *self = pb -> idx;
 
     KColBlockLoc bloc;
     KColWIdxBlock iblk;
@@ -563,7 +567,7 @@ bool CC KColumnIdxWriteNewBlock ( DLNode *n, void *data )
         size_t to_write;
 
         /* tell idx0 to fill in block */
-        KColumnIdx0TranscribeBlocks ( & self -> idx0,
+        KWColumnIdx0TranscribeBlocks ( & self -> idx0,
             node -> loc . start_id, node -> loc . end_id, & iblk );
         if ( iblk . idx != node -> loc . count )
             pb -> rc = RC ( rcDB, rcColumn, rcCommitting, rcNoObj, rcUnknown );
@@ -575,7 +579,7 @@ bool CC KColumnIdxWriteNewBlock ( DLNode *n, void *data )
             if ( pb -> rc == 0 )
             {
                 /* write block appropriately */
-                pb -> rc = KColumnIdx2Write ( & self -> idx2,
+                pb -> rc = KWColumnIdx2Write ( & self -> idx2,
                     & bloc . pg, KColWIdxBlockPersistPtr ( & iblk, & bloc ), to_write );
             }
         }
@@ -585,13 +589,13 @@ bool CC KColumnIdxWriteNewBlock ( DLNode *n, void *data )
         if ( pb -> rc == 0 )
         {
             /* write idx1 block location information */
-            pb -> rc = KColumnIdx1Commit ( & self -> idx1, & bloc );
+            pb -> rc = KWColumnIdx1Commit ( & self -> idx1, & bloc );
             if ( pb -> rc == 0 )
             {
                 /* update the header */
                 if ( ++ self -> commit_count >= pb -> commit_freq )
                 {
-                    pb -> rc = KColumnIdx1WriteHeader ( & self -> idx1,
+                    pb -> rc = KWColumnIdx1WriteHeader ( & self -> idx1,
                         pb -> data_eof, self -> idx0 . count,
                         self -> idx2 . eof + bloc . u . blk . size,
                         pb -> pgsize, pb -> checksum );
@@ -602,12 +606,12 @@ bool CC KColumnIdxWriteNewBlock ( DLNode *n, void *data )
                 if ( pb -> rc == 0 )
                 {
                     /* done writing block */
-                    KColumnIdx2Commit ( & self -> idx2, to_write );
+                    KWColumnIdx2Commit ( & self -> idx2, to_write );
                     return false;
                 }
 
                 /* revert idx1 */
-                KColumnIdx1Revert ( & self -> idx1, bloc . start_id, bloc . id_range );
+                KWColumnIdx1Revert ( & self -> idx1, bloc . start_id, bloc . id_range );
             }
         }
     }
@@ -615,19 +619,19 @@ bool CC KColumnIdxWriteNewBlock ( DLNode *n, void *data )
     return true;
 }
 
-/* KColumnIdxFixIdx1
+/* KWColumnIdxFixIdx1
  */
 static
-bool CC KColumnIdxFixIdx1 ( DLNode *n, void *data )
+bool CC KWColumnIdxFixIdx1 ( DLNode *n, void *data )
 {
     const Idx0EdgeNode *node = ( const Idx0EdgeNode* ) n;
-    return KColumnIdx1Revert ( data, node -> loc . start_id,
+    return KWColumnIdx1Revert ( data, node -> loc . start_id,
         ( uint32_t ) ( node -> loc . end_id  - node -> loc . start_id ) );
 }
 
-/* KColumnIdxReindex
+/* KWColumnIdxReindex
  */
-rc_t KColumnIdxReindex ( KColumnIdx *self, KMD5SumFmt *md5,
+rc_t KWColumnIdxReindex ( KWColumnIdx *self, KMD5SumFmt *md5,
     uint32_t commit_freq, uint64_t data_eof, size_t pgsize, int32_t checksum )
 {
     rc_t rc;
@@ -639,11 +643,11 @@ rc_t KColumnIdxReindex ( KColumnIdx *self, KMD5SumFmt *md5,
     DLListInit ( & edges );
 
     /* map the new entries */
-    rc = KColumnIdx0DefineBlocks ( & self -> idx0,
-        KColumnIdxRecordIdx0Edges, & edges, pgsize );
+    rc = KWColumnIdx0DefineBlocks ( & self -> idx0,
+        KWColumnIdxRecordIdx0Edges, & edges, pgsize );
     if ( rc == 0 )
     {
-        rc = KColumnIdxCollapseBlocks ( self, & edges );
+        rc = KWColumnIdxCollapseBlocks ( self, & edges );
         if ( rc == 0 )
         {
             /* preserve for restoration */
@@ -660,20 +664,20 @@ rc_t KColumnIdxReindex ( KColumnIdx *self, KMD5SumFmt *md5,
             pb . bswap = self -> idx1 . bswap;
 
             /* write new blocks */
-            DLListDoUntil ( & edges, false, KColumnIdxWriteNewBlock, & pb );
+            DLListDoUntil ( & edges, false, KWColumnIdxWriteNewBlock, & pb );
             if ( ( rc = pb . rc ) == 0 )
             {
                 /* idx2 is correct,
                    idx1 has proper count and bst,
                    idx0 needs to whack bst and file,
                    idx1 needs to update header */
-                rc = KColumnIdx1WriteHeader ( & self -> idx1,
+                rc = KWColumnIdx1WriteHeader ( & self -> idx1,
                     data_eof, 0, self -> idx2 . eof,
                     pgsize, checksum );
                 if ( rc == 0 )
                 {
                     self -> commit_count = 0;
-                    KColumnIdx0Truncate ( & self -> idx0 );
+                    KWColumnIdx0Truncate ( & self -> idx0 );
                     DLListWhack ( & edges, Idx0EdgeNodeWhack, NULL );
                     return 0;
                 }
@@ -683,7 +687,7 @@ rc_t KColumnIdxReindex ( KColumnIdx *self, KMD5SumFmt *md5,
             self -> idx2 . eof = idx2_eof;
 
             /* restore idx1 count and fix bst */
-            DLListDoUntil ( & edges, false, KColumnIdxFixIdx1, & self -> idx1 );
+            DLListDoUntil ( & edges, false, KWColumnIdxFixIdx1, & self -> idx1 );
             self -> idx1 . count = count;
         }
     }
