@@ -66,6 +66,13 @@ rc_t CC KService1NameWithVersion ( const struct KNSManager * mgr,
     const char * ticket, VRemoteProtocols protocols,
     const struct VPath ** remote, const struct VPath ** mapping,
     bool refseq_ctx, const char * names_version, bool aProtected );
+VFS_EXTERN
+rc_t CC KService1NameWithQuality(const struct KNSManager * mgr,
+    const char * cgi_url, const char * acc, size_t acc_sz,
+    const char * ticket, VRemoteProtocols protocols,
+    const struct VPath ** remote, const struct VPath ** mapping,
+    bool refseq_ctx, const char * names_version, bool aProtected,
+    const char * quality, const struct VPath * query);
 
 
 /******************************** KSrvResponse ********************************/
@@ -128,12 +135,10 @@ const KSrvResponse * KSrvRunIteratorGetResponse(
    2: don't resolve */
 rc_t KServiceResolveName ( struct KService * service, int resolve );
 
-/* Set quality type in service request */
-rc_t KServiceSetQuality(KService * self, VQuality quality);
-rc_t KServiceGetQuality(const KService * self, int32_t * quality);
-
-rc_t KServiceResolve(KService * self, bool local, bool remote);
 bool KServiceSkipLocal(const KService * self);
+bool KServiceSkipRemote(const KService * self);
+
+rc_t KServiceInitQuality(KService * self);
 
 /* call to set VResolverCacheEnable to vrAlwaysEnable
    to simulate prefetch mode
@@ -149,13 +154,15 @@ rc_t KServiceNamesExecute ( struct KService * self, VRemoteProtocols protocols,
 
 rc_t KServiceNamesExecuteExtImpl ( struct KService * self,
     VRemoteProtocols protocols, const char * cgi, const char * version,
-    const struct KSrvResponse ** response, const char * expected );
+    const struct KSrvResponse ** response, const char * expected, int idx );
 
 /***************** Interface services.c -> remote-services.c  *****************/
+rc_t KServiceInitNamesRequestWithVersion(KService * self,
+    VRemoteProtocols protocols, const char * cgi, const char * version,
+    bool aProtected, bool adjustVersion, int idx);
 rc_t KServiceGetResponse(const KService * self, const KSrvResponse ** response);
 rc_t KServiceGetConfig ( struct KService * self, const struct KConfig ** kfg);
-rc_t KServiceGetVFSManager ( const KService * self,
-    const struct VFSManager ** mgr );
+rc_t KServiceGetVFSManager ( const KService * self, struct VFSManager ** mgr );
 rc_t KServiceGetResolver ( struct KService * self, const String * ticket,
                            VResolver ** resolver );
 rc_t KServiceGetResolverForProject(struct KService * self, uint32_t project,
@@ -179,6 +186,8 @@ rc_t KServiceAddLocalAndCacheToResponse(KService * self,
 /* don't release cache */
 rc_t KServiceGetServiceCache(KService * self, struct ServicesCache ** cache);
 
+rc_t KServiceHasQuery(const KService * self);
+bool KServiceAnyFormatRequested(const KService * self);
 /******************************** TESTS ***************************************/
 typedef struct {
     const char * id;
@@ -206,13 +215,15 @@ rc_t KServiceRequestTestNames1 ( const struct KNSManager * mgr,
     const char * ticket, VRemoteProtocols protocols,
     EObjectType objectType );
 
-/* Parse "buffer" as names-3.0 response.
+/* Parse "buffer" as name s-3.0 response.
    Do not log "errorsToIgnore" messages during response processing */
+#ifdef NAMESCGI
 rc_t KServiceNames3_0StreamTest ( const char * buffer,
     const struct KSrvResponse ** response, int errorsToIgnore );
 rc_t KServiceNames3_0StreamTestMany ( const char * buffer,
     const struct KSrvResponse ** response, int errorsToIgnore,
     int itemsInRequest );
+#endif
 rc_t KServiceNamesRequestTest ( const struct KNSManager * mgr, const char * b,
     const char * cgi, VRemoteProtocols protocols,
     const SServiceRequestTestData * d, ... );
@@ -221,13 +232,14 @@ rc_t KServiceSearchTest1
     ( const struct KNSManager * mgr, const char * cgi, const char * acc );
 rc_t KServiceSearchTest (
     const struct KNSManager * mgr, const char * cgi, const char * acc, ... );
+
 /******************************************************************************/
 
-/* THE FOLLOWING DEFINE TURNS ON COMPARING OLD/NEW RESOLVING CALLS AND
-   ASSERTING WHEN THE RESULTS DO NOT MATCH.
-   REMOVE IT WHEN MERGING THE BRANCH 
-#define TESTING_SERVICES_VS_OLD_RESOLVING 1 */
-
+/* cache SDL response */
+rc_t VFSManagerSetCachedKSrvResponse
+(struct VFSManager * self, const char * id, const KSrvResponse * resp);
+rc_t VFSManagerGetCachedKSrvResponse
+(const struct VFSManager * self, const char * id, const KSrvResponse ** resp);
 
 #ifdef __cplusplus
 }
